@@ -5,26 +5,23 @@
 
 #include "kalzium.h"
 
-#include <element.h>
-#include <kdeeduglossary.h>
-#include "prefs.h"
-#include "ui_settings_colors.h"
-#include "ui_settings_gradients.h"
-#include "ui_settings_calc.h"
-#include "detailinfodlg.h"
 #include "detailedgraphicaloverview.h"
+#include "detailinfodlg.h"
+#include "exportdialog.h"
 #include "gradientwidget_impl.h"
 #include "kalziumdataobject.h"
+#include "kalziumgradienttype.h"
 #include "kalziumnumerationtype.h"
 #include "kalziumschemetype.h"
-#include "kalziumgradienttype.h"
 #include "legendwidget.h"
-#include "exportdialog.h"
+#include "prefs.h"
+#include "psetables.h"
 #include "search.h"
 #include "searchwidget.h"
 #include "tableinfowidget.h"
-#include "psetables.h"
 #include <config-kalzium.h>
+#include <element.h>
+#include <kdeeduglossary.h>
 
 #ifdef HAVE_FACILE
 #include "eqchemview.h"
@@ -40,10 +37,7 @@
 
 #include <QDockWidget>
 #include <QFileDialog>
-#include <QGridLayout>
 #include <QIcon>
-#include <QKeyEvent>
-#include <QLocale>
 #include <QMessageBox>
 #include <QRegularExpression>
 #include <QStandardPaths>
@@ -52,15 +46,15 @@
 #include <QUrl>
 
 #include <KActionCollection>
-#include <KConfigDialog>
 #include <KLocalizedString>
 #include <KPluginLoader>
 #include <KSelectAction>
 #include <KStandardAction>
 
-#define IDS_ELEMENTINFO     7
+#define IDS_ELEMENTINFO 7
 
-Kalzium::Kalzium() : KXmlGuiWindow(nullptr)
+Kalzium::Kalzium()
+    : KXmlGuiWindow(nullptr)
 {
     setObjectName(QStringLiteral("KalziumMainWindow"));
 
@@ -78,26 +72,24 @@ Kalzium::Kalzium() : KXmlGuiWindow(nullptr)
     // reading the elements from file
     KalziumDataObject::instance();
 
-    Search *newsearch = new Search();
+    auto newsearch = new Search();
     KalziumDataObject::instance()->setSearch(newsearch);
 
     // Main pse-Table Tablewidget
-    QWidget *pseTempWidget = new QWidget(this);
-    QVBoxLayout *layout = new QVBoxLayout(pseTempWidget);
+    auto pseTempWidget = new QWidget(this);
+    auto layout = new QVBoxLayout(pseTempWidget);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(2);
 
-    SearchWidget *searchWidget = new SearchWidget(pseTempWidget);
+    auto searchWidget = new SearchWidget(pseTempWidget);
     searchWidget->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum));
 
     // Creating the periodic table
     m_periodicTable = new PeriodicTableView(pseTempWidget);
 
     // Connecting the search to the periodic table
-    connect(newsearch, &Search::searchChanged,
-             KalziumElementProperty::instance(), &KalziumElementProperty::propertyChanged);
-    connect(newsearch, &Search::searchReset,
-             KalziumElementProperty::instance(), &KalziumElementProperty::propertyChanged);
+    connect(newsearch, &Search::searchChanged, KalziumElementProperty::instance(), &KalziumElementProperty::propertyChanged);
+    connect(newsearch, &Search::searchReset, KalziumElementProperty::instance(), &KalziumElementProperty::propertyChanged);
 
     layout->addWidget(searchWidget);
     layout->addWidget(m_periodicTable);
@@ -106,7 +98,7 @@ Kalzium::Kalzium() : KXmlGuiWindow(nullptr)
 
     connect(m_periodicTable->pseScene(), &PeriodicTableScene::elementChanged, this, &Kalzium::openInformationDialog);
     connect(m_periodicTable->pseScene(), &PeriodicTableScene::elementHovered, this, &Kalzium::elementHover);
-    connect(this, &Kalzium::numerationChanged,  m_periodicTable, &PeriodicTableView::numerationChange);
+    connect(this, &Kalzium::numerationChanged, m_periodicTable, &PeriodicTableView::numerationChange);
 
     // layouting
     setupSidebars();
@@ -122,7 +114,7 @@ void Kalzium::setupActions()
     connect(export_action, &QAction::triggered, this, &Kalzium::slotShowExportDialog);
 
     // the action for switching look: color schemes and gradients
-    QStringList schemes = KalziumElementProperty::instance()->schemeList();    /*KalziumSchemeTypeFactory::instance()->schemes();*/
+    QStringList schemes = KalziumElementProperty::instance()->schemeList(); /*KalziumSchemeTypeFactory::instance()->schemes();*/
     QStringList gradients = KalziumElementProperty::instance()->gradientList();
 
     // the action for switching look: schemes
@@ -131,7 +123,7 @@ void Kalzium::setupActions()
     look_action_schemes->setItems(schemes);
     look_action_schemes->setToolBarMode(KSelectAction::MenuMode);
     look_action_schemes->setToolButtonPopupMode(QToolButton::InstantPopup);
-    connect(look_action_schemes, SIGNAL(triggered(int)), this, SLOT(slotSwitchtoLookScheme(int)));
+    connect(look_action_schemes, &KSelectAction::indexTriggered, this, &Kalzium::slotSwitchtoLookScheme);
 
     // the action for switching look: gradients
     look_action_gradients = actionCollection()->add<KSelectAction>(QStringLiteral("view_look_onlygradients"));
@@ -139,22 +131,22 @@ void Kalzium::setupActions()
     look_action_gradients->setItems(gradients);
     look_action_gradients->setToolBarMode(KSelectAction::MenuMode);
     look_action_gradients->setToolButtonPopupMode(QToolButton::InstantPopup);
-    connect(look_action_gradients, SIGNAL(triggered(int)), this, SLOT(slotSwitchtoLookGradient(int)));
+    connect(look_action_gradients, &KSelectAction::indexTriggered, this, &Kalzium::slotSwitchtoLookGradient);
 
     // the action for switching tables
     QStringList table_schemes = pseTables::instance()->tables();
-    table_action =  actionCollection()->add<KSelectAction>(QStringLiteral("view_table"));
+    table_action = actionCollection()->add<KSelectAction>(QStringLiteral("view_table"));
     table_action->setText(i18n("&Tables"));
     table_action->setItems(table_schemes);
     table_action->setCurrentItem(Prefs::table());
-    connect(table_action, SIGNAL(triggered(int)), this, SLOT(slotSwitchtoTable(int)));
+    connect(table_action, &KSelectAction::indexTriggered, this, &Kalzium::slotSwitchtoTable);
 
     // the actions for switching numeration
     numeration_action = actionCollection()->add<KSelectAction>(QStringLiteral("view_numerationtype"));
     numeration_action->setText(i18n("&Numeration"));
     numeration_action->setItems(KalziumNumerationTypeFactory::instance()->numerations());
     numeration_action->setCurrentItem(Prefs::numeration());
-    connect(numeration_action, SIGNAL(triggered(int)), this, SLOT(slotSwitchtoNumeration(int)));
+    connect(numeration_action, SIGNAL(indexTriggered(int)), this, SLOT(slotSwitchtoNumeration(int)));
 
     // tools actions
     m_pPlotAction = actionCollection()->addAction(QStringLiteral("tools_plotdata"));
@@ -169,7 +161,7 @@ void Kalzium::setupActions()
     m_pcalculator->setWhatsThis(i18nc("WhatsThis Help", "This is the calculator, it performs basic chemical calculations."));
     connect(m_pcalculator, &QAction::triggered, this, &Kalzium::showCalculator);
 
-    m_pIsotopeTableAction= actionCollection()->addAction(QStringLiteral("tools_isotopetable"));
+    m_pIsotopeTableAction = actionCollection()->addAction(QStringLiteral("tools_isotopetable"));
     m_pIsotopeTableAction->setText(i18n("&Isotope Table..."));
     m_pIsotopeTableAction->setIcon(QIcon::fromTheme(QStringLiteral("isotopemap")));
     m_pIsotopeTableAction->setWhatsThis(i18nc("WhatsThis Help", "This table shows all of the known isotopes of the chemical elements."));
@@ -235,7 +227,6 @@ void Kalzium::setupActions()
 
     m_legendWidget->LockWidget();
 
-
     slotSwitchtoLookGradient(KalziumElementProperty::instance()->gradientId());
     slotSwitchtoLookScheme(KalziumElementProperty::instance()->schemeId());
 
@@ -257,26 +248,22 @@ void Kalzium::setupSidebars()
     m_legendWidget = new LegendWidget(this);
     m_legendDock = new QDockWidget(i18n("Legend"), this);
     m_legendDock->setObjectName(QStringLiteral("kalzium-legend"));
-    m_legendDock->setFeatures(QDockWidget::AllDockWidgetFeatures);
+    m_legendDock->setFeatures(QDockWidget::DockWidgetClosable|QDockWidget::DockWidgetMovable|QDockWidget::DockWidgetFloatable);
     m_legendDock->setWidget(m_legendWidget);
 
-    connect(m_legendDock, &QDockWidget::dockLocationChanged,
-            m_legendWidget, &LegendWidget::setDockArea);
-    connect(m_legendWidget, &LegendWidget::elementMatched,
-            m_periodicTable, &PeriodicTableView::slotSelectAdditionalElement);
-    connect(m_legendWidget, &LegendWidget::resetElementMatch,
-            m_periodicTable, &PeriodicTableView::slotUnSelectElements);
+    connect(m_legendDock, &QDockWidget::dockLocationChanged, m_legendWidget, &LegendWidget::setDockArea);
+    connect(m_legendWidget, &LegendWidget::elementMatched, m_periodicTable, &PeriodicTableView::slotSelectAdditionalElement);
+    connect(m_legendWidget, &LegendWidget::resetElementMatch, m_periodicTable, &PeriodicTableView::slotUnSelectElements);
 
     m_TableInfoWidget = new TableInfoWidget(this);
     m_tableDock = new QDockWidget(i18n("Table Information"), this);
     m_tableDock->setWidget(m_TableInfoWidget);
     m_tableDock->setObjectName(QStringLiteral("kalzium-tableinfo"));
-    m_tableDock->setFeatures(QDockWidget::AllDockWidgetFeatures);
-
+    m_tableDock->setFeatures(QDockWidget::DockWidgetClosable|QDockWidget::DockWidgetMovable|QDockWidget::DockWidgetFloatable);
 
     m_dockWin = new QDockWidget(i18n("Information"), this);
     m_dockWin->setObjectName(QStringLiteral("kalzium-sidebar"));
-    m_dockWin->setFeatures(QDockWidget::AllDockWidgetFeatures);
+    m_dockWin->setFeatures(QDockWidget::DockWidgetClosable|QDockWidget::DockWidgetMovable|QDockWidget::DockWidgetFloatable);
     m_dockWin->setMinimumWidth(250);
 
     m_toolbox = new QToolBox(m_dockWin);
@@ -291,12 +278,9 @@ void Kalzium::setupSidebars()
     m_gradientWidget = new GradientWidgetImpl(m_toolbox);
     m_gradientWidget->setObjectName(QStringLiteral("viewtWidget"));
 
-    connect(m_gradientWidget, &GradientWidgetImpl::gradientValueChanged,
-             KalziumElementProperty::instance(), &KalziumElementProperty::setSliderValue);
-    connect(m_gradientWidget->scheme_combo, SIGNAL(currentIndexChanged(int)),
-             this, SLOT(slotSwitchtoLookScheme(int)));
-    connect(m_gradientWidget->gradient_combo, SIGNAL(currentIndexChanged(int)),
-             this, SLOT(slotSwitchtoLookGradient(int)));
+    connect(m_gradientWidget, &GradientWidgetImpl::gradientValueChanged, KalziumElementProperty::instance(), &KalziumElementProperty::setSliderValue);
+    connect(m_gradientWidget->scheme_combo, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSwitchtoLookScheme(int)));
+    connect(m_gradientWidget->gradient_combo, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSwitchtoLookGradient(int)));
 
     m_toolbox->addItem(m_gradientWidget, QIcon::fromTheme(QStringLiteral("statematter")), i18n("View"));
 
@@ -309,7 +293,7 @@ void Kalzium::setupSidebars()
 
 void Kalzium::slotExportTable()
 {
-    QString fileName = QFileDialog::getSaveFileName(this, i18n("Save Kalzium's Table In"), QString(), i18n("Image files (*.png *.xpm *.jpg *.svg)"));
+    const QString fileName = QFileDialog::getSaveFileName(this, i18n("Save Kalzium's Table In"), QString(), i18n("Image files (*.png *.xpm *.jpg *.svg)"));
 
     if (fileName.endsWith(QLatin1String(".svg"))) {
         m_periodicTable->generateSvg(fileName);
@@ -322,22 +306,22 @@ void Kalzium::slotExportTable()
 void Kalzium::slotGlossary()
 {
     if (!m_glossarydlg) {
-      // creating the glossary dialog and loading the glossaries we have
-      m_glossarydlg = new GlossaryDialog(this);
-      m_glossarydlg->setObjectName(QStringLiteral("glossary"));
-      QString dir = QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("data/"), QStandardPaths::LocateDirectory);
-      dir = QFileInfo(dir).absolutePath();
-      QString picturepath = dir + "/bg.jpg";
-      QUrl u = QUrl::fromLocalFile(dir + "/knowledge.xml");
-      Glossary *g = new Glossary(u);
-      g->setName(i18n("Knowledge"));
-      g->setBackgroundPicture(picturepath);
-      m_glossarydlg->addGlossary(g, true);
-      u = QUrl::fromLocalFile(dir + "/tools.xml");
-      g = new Glossary(u, dir + "/toolpics/");
-      g->setName(i18n("Tools"));
-      g->setBackgroundPicture(picturepath);
-      m_glossarydlg->addGlossary(g, true);
+        // creating the glossary dialog and loading the glossaries we have
+        m_glossarydlg = new GlossaryDialog(this);
+        m_glossarydlg->setObjectName(QStringLiteral("glossary"));
+        QString dir = QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("data/"), QStandardPaths::LocateDirectory);
+        dir = QFileInfo(dir).absolutePath();
+        const QString picturepath = dir + QStringLiteral("/bg.jpg");
+        QUrl u = QUrl::fromLocalFile(dir + "/knowledge.xml");
+        auto g = new Glossary(u);
+        g->setName(i18n("Knowledge"));
+        g->setBackgroundPicture(picturepath);
+        m_glossarydlg->addGlossary(g, true);
+        u = QUrl::fromLocalFile(dir + "/tools.xml");
+        g = new Glossary(u, dir + "/toolpics/");
+        g->setName(i18n("Tools"));
+        g->setBackgroundPicture(picturepath);
+        m_glossarydlg->addGlossary(g, true);
     }
 
     m_glossarydlg->show();
@@ -346,7 +330,7 @@ void Kalzium::slotGlossary()
 void Kalzium::slotRS()
 {
     if (!m_rsDialog) {
-      m_rsDialog = new RSDialog(this);
+        m_rsDialog = new RSDialog(this);
     }
     m_rsDialog->show();
 }
@@ -354,7 +338,7 @@ void Kalzium::slotRS()
 void Kalzium::slotOBConverter()
 {
 #ifdef HAVE_OPENBABEL
-    KOpenBabel * d = new KOpenBabel(this);
+    KOpenBabel *d = new KOpenBabel(this);
     d->setAttribute(Qt::WA_DeleteOnClose);
     d->show();
 #endif
@@ -369,7 +353,7 @@ MoleculeDialog *Kalzium::slotMoleculeviewer()
         return nullptr;
     }
 
-    MoleculeDialog * d = new MoleculeDialog(this);
+    MoleculeDialog *d = new MoleculeDialog(this);
     d->show();
     return d;
 
@@ -391,23 +375,24 @@ MoleculeDialog *Kalzium::slotMoleculeviewer()
 void Kalzium::slotTables()
 {
     if (!m_tablesDialog) {
-      m_tablesDialog = new TablesDialog(this);
+        m_tablesDialog = new TablesDialog(this);
     }
     m_tablesDialog->show();
 }
 
 void Kalzium::slotIsotopeTable()
 {
-   if (!m_isotopeDialog) {
-     m_isotopeDialog = new IsotopeTableDialog(this);
-   }
-   m_isotopeDialog->show();
+    if (!m_isotopeDialog) {
+        m_isotopeDialog = new IsotopeTableDialog(this);
+        connect(Prefs::self(), &Prefs::isotopeTableModeChanged, m_isotopeDialog, &IsotopeTableDialog::updateMode);
+    }
+    m_isotopeDialog->show();
 }
 
 void Kalzium::slotPlotData()
 {
     if (!m_elementDataPlotter) {
-      m_elementDataPlotter = new ElementDataViewer(this);
+        m_elementDataPlotter = new ElementDataViewer(this);
     }
     m_elementDataPlotter->show();
 }
@@ -415,9 +400,9 @@ void Kalzium::slotPlotData()
 void Kalzium::showCalculator()
 {
     if (!m_calculator) {
-      m_calculator = new calculator(this);
+        m_calculator = new calculator(this);
     }
-    m_calculator -> show();
+    m_calculator->show();
 }
 
 void Kalzium::slotSwitchtoTable(int index)
@@ -479,53 +464,21 @@ void Kalzium::slotSwitchtoLookScheme(int which)
 
 void Kalzium::showSettingsDialog()
 {
-    if (KConfigDialog::showDialog(QStringLiteral("settings"))) {
+    if (KalziumConfigDialog::showDialog(QStringLiteral("settings"))) {
         return;
     }
 
-    //KConfigDialog didn't find an instance of this dialog, so lets create it :
-    KConfigDialog *dialog = new KConfigDialog(this,QStringLiteral("settings"), Prefs::self());
+    // KalziumConfigDialog didn't find an instance of this dialog, so lets create it :
+    m_configDialog = new KalziumConfigDialog(this, QStringLiteral("settings"), Prefs::self());
 
-    // colors page
-    Ui_setupColors ui_colors;
-    QWidget *w_colors = new QWidget(this);
-    w_colors->setObjectName(QStringLiteral("colors_page"));
-    ui_colors.setupUi(w_colors);
-    dialog->addPage(w_colors, i18n("Schemes"), QStringLiteral("preferences-desktop-color"));
+    connect(m_configDialog, &KalziumConfigDialog::settingsChanged, this, &Kalzium::slotUpdateSettings);
+    connect(m_configDialog, &KalziumConfigDialog::settingsChanged, m_gradientWidget, &GradientWidgetImpl::slotGradientChanged);
 
-    // gradients page
-    Ui_setupGradients ui_gradients;
-    QWidget *w_gradients = new QWidget(this);
-    w_gradients->setObjectName(QStringLiteral("gradients_page"));
-    ui_gradients.setupUi(w_gradients);
-    dialog->addPage(w_gradients, i18n("Gradients"), QStringLiteral("preferences-desktop-color"));
-
-    // units page
-    m_unitsDialog = new UnitSettingsDialog(this);
-    m_unitsDialog->setObjectName(QStringLiteral("units_page"));
-    dialog->addPage(m_unitsDialog, i18n("Units"), QStringLiteral("system-run"));
-
-    Ui_setupCalc ui_calc;
-    QWidget *w_calc = new QWidget(this);
-    ui_calc.setupUi(w_calc);
-    dialog->addPage(w_calc, i18n("Calculator"), QStringLiteral("accessories-calculator"));
-
-    connect(dialog, &KConfigDialog::settingsChanged, this, &Kalzium::slotUpdateSettings);
-    connect(dialog, &KConfigDialog::settingsChanged, m_gradientWidget, &GradientWidgetImpl::slotGradientChanged);
-
-    dialog->show();
+    m_configDialog->show();
 }
 
 void Kalzium::slotUpdateSettings()
 {
-    Prefs::setLengthUnit(m_unitsDialog->getLenghtUnitId());
-
-    Prefs::setEnergiesUnit(m_unitsDialog->getEnergyUnitId());
-
-    Prefs::setTemperatureUnit(m_unitsDialog->getTemperatureUnitId());
-
-    Prefs::self()->save();
-
     /*This slot function calls change the color of pse elements immediately after prefs change*/
     slotSwitchtoLookGradient(Prefs::colorgradientbox());
     slotSwitchtoLookScheme(Prefs::colorschemebox());
@@ -541,7 +494,7 @@ void Kalzium::slotShowExportDialog()
 
 void Kalzium::setupStatusBar()
 {
-    QStatusBar *statusBar = new QStatusBar(this);
+    auto statusBar = new QStatusBar(this);
     setStatusBar(statusBar);
 
     m_elementInfo = new QLabel(QLatin1String(""));
@@ -554,7 +507,8 @@ void Kalzium::elementHover(int num)
 {
     //     extractIconicInformationAboutElement(num);
     Element *e = KalziumDataObject::instance()->element(num);
-    m_elementInfo->setText(i18nc("For example: \"Carbon (6), Mass: 12.0107 u\"", "%1 (%2), Mass: %3 u",
+    m_elementInfo->setText(i18nc("For example: \"Carbon (6), Mass: 12.0107 u\"",
+                                 "%1 (%2), Mass: %3 u",
                                  e->dataAsString(ChemicalDataObject::name),
                                  e->dataAsString(ChemicalDataObject::atomicNumber),
                                  e->dataAsString(ChemicalDataObject::mass)));
@@ -566,10 +520,10 @@ void Kalzium::elementHover(int num)
 // FIXME What is that function for? Does not seem to do anything useful... yet?
 void Kalzium::extractIconicInformationAboutElement(int elementNumber)
 {
-    QString setname = QStringLiteral("school");
+    const QString setname = QStringLiteral("school");
     QString pathname = QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, QStringLiteral("data/iconsets/"), QStandardPaths::LocateDirectory);
     pathname = QFileInfo(pathname).absolutePath();
-    QString filename = pathname + setname + '/' + "iconinformation.txt";
+    const QString filename = pathname + setname + '/' + "iconinformation.txt";
 
     QFile file(filename);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -587,7 +541,7 @@ void Kalzium::extractIconicInformationAboutElement(int elementNumber)
     }
 
     QString realText = QStringLiteral("Moin dies ist ein test!");
-//X         QString realText = infoline.remove(QRegularExpression("\\d+ "));
+    // X         QString realText = infoline.remove(QRegularExpression("\\d+ "));
 }
 
 void Kalzium::openInformationDialog(int number)
@@ -598,17 +552,14 @@ void Kalzium::openInformationDialog(int number)
         m_infoDialog = new DetailedInfoDlg(number, this);
 
         // Remove the selection when this dialog finishes or hides.
-        connect(m_infoDialog, &DetailedInfoDlg::elementChanged,
-                m_periodicTable, &PeriodicTableView::slotSelectOneElement);
-        connect(m_infoDialog, &DetailedInfoDlg::elementChanged,
-                this, &Kalzium::elementHover);
+        connect(m_infoDialog, &DetailedInfoDlg::elementChanged, m_periodicTable, &PeriodicTableView::slotSelectOneElement);
+        connect(m_infoDialog, &DetailedInfoDlg::elementChanged, this, &Kalzium::elementHover);
     }
 
     m_infoDialog->setTableType(m_periodicTable->table());
     m_infoDialog->show();
 }
 
-
 Kalzium::~Kalzium()
 {
     delete m_periodicTable;
@@ -634,6 +585,5 @@ void Kalzium::loadMolecule(const QString &moleculeFile)
 
 QSize Kalzium::sizeHint() const
 {
-    return QSize(700, 500);
+    return {700, 500};
 }
-
